@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#    Copyright (C) 2019-2022  Marcus Rickert
+#    Copyright (C) 2019-2023  Marcus Rickert
 #
 #    See https://github.com/marcus67/python_base_app
 #
@@ -44,7 +44,6 @@ fi
 
 EXTRA_INDEX_URL="${{ python_packages[0][8] }}"
 
-
 if [ "${EXTRA_INDEX_URL}" == "" ] ; then
   echo "No extra PIP indexes defined!"
   EXTRA_INDEX_OPTION=
@@ -72,4 +71,4 @@ else
 fi
 
 echo "Using pip3 binary at ${PIP3}..."
-${PIP3} $@ ${EXTRA_INDEX_OPTION}
+${PIP3} "$@" ${EXTRA_INDEX_OPTION}
